{ config, lib, pkgs, ... }:

let 
  home-manager = fetchGit {
    url = "https://github.com/nix-community/home-manager";
    rev = "a98ec6ec158686387d66654ea96153ec06be33d7";
  };
in {
  imports = [
    ../../modules
    "${home-manager}/nixos"
    ./pbb.nix
    ./users.nix
  ];

  nixpkgs.overlays = [
    (self: super: import ../../pkgs { nixpkgs = super.path; })
  ];

  boot.kernelPackages = lib.mkDefault pkgs.linuxPackages_latest;
  boot.kernelParams = [ "quiet" ];

  networking.domain = lib.mkDefault "hacc.space";
  petabyte.nftables = {
    enable = lib.mkDefault true;
  };

  services.journald.extraConfig = "SystemMaxUse=512M";
  nix.gc.automatic = lib.mkDefault true;
  nix.gc.options = lib.mkDefault "--delete-older-than 1w";
  nix.trustedUsers = [ "root" "@wheel" ];
  environment.variables.EDITOR = "vim";

  services.openssh.enable = true;
  services.openssh.ports = lib.mkDefault [ 62954 ];
  services.openssh.passwordAuthentication = false;
  services.openssh.challengeResponseAuthentication = false;
  services.openssh.permitRootLogin = lib.mkDefault "prohibit-password";
  services.openssh.extraConfig = "StreamLocalBindUnlink yes";
  security.sudo.wheelNeedsPassword = lib.mkDefault false;

  i18n.defaultLocale = "en_IE.UTF-8";
  time.timeZone = "UTC";
  console = {
    font = "Lat2-Terminus16";
    keyMap = "de";
  };
  programs.mtr.enable = true;

  environment.systemPackages = with pkgs; [
    smartmontools lm_sensors htop tcpdump nload iftop
#   bottom 
    ripgrep
    git wget
    kitty.terminfo
    rsync pv progress
    parallel bc
    usbutils pciutils
    cryptsetup gptfdisk
    zstd p7zip
    file
    whois
    iperf
    fd
    exa
    socat
    tmux
    gnupg
    vim
    patchelf
    binutils
    dnsutils
    flashrom ifdtool cbfstool nvramtool
    nmap
  ];

  petabyte.vnstat = {
    enable = true;
    nginx.enable = true;
  };

  security.acme.email = "info+acme@hacc.space";
  security.acme.acceptTerms = true;
}
